@@ -19,7 +19,7 @@ from cProfile import Profile
 from datetime import datetime
 from tempfile import gettempdir
 
-import Image
+from PIL import Image
 import networkx as nx
 from mako.lookup import TemplateLookup
 from paste.urlparser import StaticURLParser
@@ -276,7 +276,7 @@ class ProfilingMiddleware(object):
         else:
             deleted_rows = 0
 
-        resp.text = "%d row(s) deleted." % deleted_rows
+        resp.text = u"%d row(s) deleted." % deleted_rows
 
         return resp
 
@@ -298,7 +298,7 @@ class ProfilingMiddleware(object):
         # If the Session doesn't exist, return an appropriate error
         if not session:
             resp.status = "404 Not Found"
-            resp.text = "Session `%s' not found." % session_uuid
+            resp.text = u"Session `%s' not found." % session_uuid
         else:
             # Otherwise, prepare the graph for display!
             cutoff_percentage = float(
@@ -309,7 +309,7 @@ class ProfilingMiddleware(object):
                 session._graph, cutoff_time, True)
             chart_values = time_per_field(session._graph, root_nodes,
                                         self.chart_packages)
-            resp.text = self.get_template('tree.tmpl').render_unicode(
+            resp.unicode_body = self.get_template('tree.tmpl').render_unicode(
                 session=session,
                 graph=graph,
                 root_nodes=root_nodes,
@@ -319,7 +319,6 @@ class ProfilingMiddleware(object):
                 cutoff_time=cutoff_time,
                 chart_values=chart_values
             )
-
         return resp
 
 
